"""
Type annotations for cloudfront service literal definitions.

[Documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cloudfront/literals/)

Copyright 2025 Vlad Emelianov

Usage::

    ```python
    from mypy_boto3_cloudfront.literals import CachePolicyCookieBehaviorType

    data: CachePolicyCookieBehaviorType = "all"
    ```
"""

import sys

if sys.version_info >= (3, 12):
    from typing import Literal
else:
    from typing_extensions import Literal


__all__ = (
    "CachePolicyCookieBehaviorType",
    "CachePolicyHeaderBehaviorType",
    "CachePolicyQueryStringBehaviorType",
    "CachePolicyTypeType",
    "CertificateSourceType",
    "CertificateTransparencyLoggingPreferenceType",
    "CloudFrontServiceName",
    "ConnectionModeType",
    "ContinuousDeploymentPolicyTypeType",
    "CustomizationActionTypeType",
    "DistributionDeployedWaiterName",
    "DistributionResourceTypeType",
    "DnsConfigurationStatusType",
    "DomainStatusType",
    "EventTypeType",
    "FormatType",
    "FrameOptionsListType",
    "FunctionRuntimeType",
    "FunctionStageType",
    "GeoRestrictionTypeType",
    "HttpVersionType",
    "ICPRecordalStatusType",
    "ImportSourceTypeType",
    "InvalidationCompletedWaiterName",
    "InvalidationForDistributionTenantCompletedWaiterName",
    "IpAddressTypeType",
    "IpamCidrStatusType",
    "ItemSelectionType",
    "ListCloudFrontOriginAccessIdentitiesPaginatorName",
    "ListConnectionFunctionsPaginatorName",
    "ListConnectionGroupsPaginatorName",
    "ListDistributionTenantsByCustomizationPaginatorName",
    "ListDistributionTenantsPaginatorName",
    "ListDistributionsByConnectionFunctionPaginatorName",
    "ListDistributionsByConnectionModePaginatorName",
    "ListDistributionsByTrustStorePaginatorName",
    "ListDistributionsPaginatorName",
    "ListDomainConflictsPaginatorName",
    "ListInvalidationsForDistributionTenantPaginatorName",
    "ListInvalidationsPaginatorName",
    "ListKeyValueStoresPaginatorName",
    "ListOriginAccessControlsPaginatorName",
    "ListPublicKeysPaginatorName",
    "ListStreamingDistributionsPaginatorName",
    "ListTrustStoresPaginatorName",
    "ManagedCertificateStatusType",
    "MethodType",
    "MinimumProtocolVersionType",
    "OriginAccessControlOriginTypesType",
    "OriginAccessControlSigningBehaviorsType",
    "OriginAccessControlSigningProtocolsType",
    "OriginGroupSelectionCriteriaType",
    "OriginProtocolPolicyType",
    "OriginRequestPolicyCookieBehaviorType",
    "OriginRequestPolicyHeaderBehaviorType",
    "OriginRequestPolicyQueryStringBehaviorType",
    "OriginRequestPolicyTypeType",
    "PaginatorName",
    "PriceClassType",
    "RealtimeMetricsSubscriptionStatusType",
    "ReferrerPolicyListType",
    "ResourceServiceName",
    "ResponseHeadersPolicyAccessControlAllowMethodsValuesType",
    "ResponseHeadersPolicyTypeType",
    "SSLSupportMethodType",
    "ServiceName",
    "SslProtocolType",
    "StreamingDistributionDeployedWaiterName",
    "TrustStoreStatusType",
    "ValidationTokenHostType",
    "ViewerMtlsModeType",
    "ViewerProtocolPolicyType",
    "WaiterName",
)


CachePolicyCookieBehaviorType = Literal["all", "allExcept", "none", "whitelist"]
CachePolicyHeaderBehaviorType = Literal["none", "whitelist"]
CachePolicyQueryStringBehaviorType = Literal["all", "allExcept", "none", "whitelist"]
CachePolicyTypeType = Literal["custom", "managed"]
CertificateSourceType = Literal["acm", "cloudfront", "iam"]
CertificateTransparencyLoggingPreferenceType = Literal["disabled", "enabled"]
ConnectionModeType = Literal["direct", "tenant-only"]
ContinuousDeploymentPolicyTypeType = Literal["SingleHeader", "SingleWeight"]
CustomizationActionTypeType = Literal["disable", "override"]
DistributionDeployedWaiterName = Literal["distribution_deployed"]
DistributionResourceTypeType = Literal["distribution", "distribution-tenant"]
DnsConfigurationStatusType = Literal[
    "invalid-configuration", "unknown-configuration", "valid-configuration"
]
DomainStatusType = Literal["active", "inactive"]
EventTypeType = Literal["origin-request", "origin-response", "viewer-request", "viewer-response"]
FormatType = Literal["URLEncoded"]
FrameOptionsListType = Literal["DENY", "SAMEORIGIN"]
FunctionRuntimeType = Literal["cloudfront-js-1.0", "cloudfront-js-2.0"]
FunctionStageType = Literal["DEVELOPMENT", "LIVE"]
GeoRestrictionTypeType = Literal["blacklist", "none", "whitelist"]
HttpVersionType = Literal["http1.1", "http2", "http2and3", "http3"]
ICPRecordalStatusType = Literal["APPROVED", "PENDING", "SUSPENDED"]
ImportSourceTypeType = Literal["S3"]
InvalidationCompletedWaiterName = Literal["invalidation_completed"]
InvalidationForDistributionTenantCompletedWaiterName = Literal[
    "invalidation_for_distribution_tenant_completed"
]
IpAddressTypeType = Literal["dualstack", "ipv4", "ipv6"]
IpamCidrStatusType = Literal[
    "advertised",
    "advertising",
    "deprovisioned",
    "deprovisioning",
    "failed-advertise",
    "failed-deprovision",
    "failed-provision",
    "failed-withdraw",
    "provisioned",
    "provisioning",
    "withdrawing",
    "withdrawn",
]
ItemSelectionType = Literal["all", "none", "whitelist"]
ListCloudFrontOriginAccessIdentitiesPaginatorName = Literal[
    "list_cloud_front_origin_access_identities"
]
ListConnectionFunctionsPaginatorName = Literal["list_connection_functions"]
ListConnectionGroupsPaginatorName = Literal["list_connection_groups"]
ListDistributionTenantsByCustomizationPaginatorName = Literal[
    "list_distribution_tenants_by_customization"
]
ListDistributionTenantsPaginatorName = Literal["list_distribution_tenants"]
ListDistributionsByConnectionFunctionPaginatorName = Literal[
    "list_distributions_by_connection_function"
]
ListDistributionsByConnectionModePaginatorName = Literal["list_distributions_by_connection_mode"]
ListDistributionsByTrustStorePaginatorName = Literal["list_distributions_by_trust_store"]
ListDistributionsPaginatorName = Literal["list_distributions"]
ListDomainConflictsPaginatorName = Literal["list_domain_conflicts"]
ListInvalidationsForDistributionTenantPaginatorName = Literal[
    "list_invalidations_for_distribution_tenant"
]
ListInvalidationsPaginatorName = Literal["list_invalidations"]
ListKeyValueStoresPaginatorName = Literal["list_key_value_stores"]
ListOriginAccessControlsPaginatorName = Literal["list_origin_access_controls"]
ListPublicKeysPaginatorName = Literal["list_public_keys"]
ListStreamingDistributionsPaginatorName = Literal["list_streaming_distributions"]
ListTrustStoresPaginatorName = Literal["list_trust_stores"]
ManagedCertificateStatusType = Literal[
    "expired",
    "failed",
    "inactive",
    "issued",
    "pending-validation",
    "revoked",
    "validation-timed-out",
]
MethodType = Literal["DELETE", "GET", "HEAD", "OPTIONS", "PATCH", "POST", "PUT"]
MinimumProtocolVersionType = Literal[
    "SSLv3",
    "TLSv1",
    "TLSv1.1_2016",
    "TLSv1.2_2018",
    "TLSv1.2_2019",
    "TLSv1.2_2021",
    "TLSv1.2_2025",
    "TLSv1.3_2025",
    "TLSv1_2016",
]
OriginAccessControlOriginTypesType = Literal["lambda", "mediapackagev2", "mediastore", "s3"]
OriginAccessControlSigningBehaviorsType = Literal["always", "never", "no-override"]
OriginAccessControlSigningProtocolsType = Literal["sigv4"]
OriginGroupSelectionCriteriaType = Literal["default", "media-quality-based"]
OriginProtocolPolicyType = Literal["http-only", "https-only", "match-viewer"]
OriginRequestPolicyCookieBehaviorType = Literal["all", "allExcept", "none", "whitelist"]
OriginRequestPolicyHeaderBehaviorType = Literal[
    "allExcept", "allViewer", "allViewerAndWhitelistCloudFront", "none", "whitelist"
]
OriginRequestPolicyQueryStringBehaviorType = Literal["all", "allExcept", "none", "whitelist"]
OriginRequestPolicyTypeType = Literal["custom", "managed"]
PriceClassType = Literal["None", "PriceClass_100", "PriceClass_200", "PriceClass_All"]
RealtimeMetricsSubscriptionStatusType = Literal["Disabled", "Enabled"]
ReferrerPolicyListType = Literal[
    "no-referrer",
    "no-referrer-when-downgrade",
    "origin",
    "origin-when-cross-origin",
    "same-origin",
    "strict-origin",
    "strict-origin-when-cross-origin",
    "unsafe-url",
]
ResponseHeadersPolicyAccessControlAllowMethodsValuesType = Literal[
    "ALL", "DELETE", "GET", "HEAD", "OPTIONS", "PATCH", "POST", "PUT"
]
ResponseHeadersPolicyTypeType = Literal["custom", "managed"]
SSLSupportMethodType = Literal["sni-only", "static-ip", "vip"]
SslProtocolType = Literal["SSLv3", "TLSv1", "TLSv1.1", "TLSv1.2"]
StreamingDistributionDeployedWaiterName = Literal["streaming_distribution_deployed"]
TrustStoreStatusType = Literal["active", "failed", "pending"]
ValidationTokenHostType = Literal["cloudfront", "self-hosted"]
ViewerMtlsModeType = Literal["optional", "required"]
ViewerProtocolPolicyType = Literal["allow-all", "https-only", "redirect-to-https"]
CloudFrontServiceName = Literal["cloudfront"]
ServiceName = Literal[
    "accessanalyzer",
    "account",
    "acm",
    "acm-pca",
    "aiops",
    "amp",
    "amplify",
    "amplifybackend",
    "amplifyuibuilder",
    "apigateway",
    "apigatewaymanagementapi",
    "apigatewayv2",
    "appconfig",
    "appconfigdata",
    "appfabric",
    "appflow",
    "appintegrations",
    "application-autoscaling",
    "application-insights",
    "application-signals",
    "applicationcostprofiler",
    "appmesh",
    "apprunner",
    "appstream",
    "appsync",
    "arc-region-switch",
    "arc-zonal-shift",
    "artifact",
    "athena",
    "auditmanager",
    "autoscaling",
    "autoscaling-plans",
    "b2bi",
    "backup",
    "backup-gateway",
    "backupsearch",
    "batch",
    "bcm-dashboards",
    "bcm-data-exports",
    "bcm-pricing-calculator",
    "bcm-recommended-actions",
    "bedrock",
    "bedrock-agent",
    "bedrock-agent-runtime",
    "bedrock-agentcore",
    "bedrock-agentcore-control",
    "bedrock-data-automation",
    "bedrock-data-automation-runtime",
    "bedrock-runtime",
    "billing",
    "billingconductor",
    "braket",
    "budgets",
    "ce",
    "chatbot",
    "chime",
    "chime-sdk-identity",
    "chime-sdk-media-pipelines",
    "chime-sdk-meetings",
    "chime-sdk-messaging",
    "chime-sdk-voice",
    "cleanrooms",
    "cleanroomsml",
    "cloud9",
    "cloudcontrol",
    "clouddirectory",
    "cloudformation",
    "cloudfront",
    "cloudfront-keyvaluestore",
    "cloudhsm",
    "cloudhsmv2",
    "cloudsearch",
    "cloudsearchdomain",
    "cloudtrail",
    "cloudtrail-data",
    "cloudwatch",
    "codeartifact",
    "codebuild",
    "codecatalyst",
    "codecommit",
    "codeconnections",
    "codedeploy",
    "codeguru-reviewer",
    "codeguru-security",
    "codeguruprofiler",
    "codepipeline",
    "codestar-connections",
    "codestar-notifications",
    "cognito-identity",
    "cognito-idp",
    "cognito-sync",
    "comprehend",
    "comprehendmedical",
    "compute-optimizer",
    "compute-optimizer-automation",
    "config",
    "connect",
    "connect-contact-lens",
    "connectcampaigns",
    "connectcampaignsv2",
    "connectcases",
    "connectparticipant",
    "controlcatalog",
    "controltower",
    "cost-optimization-hub",
    "cur",
    "customer-profiles",
    "databrew",
    "dataexchange",
    "datapipeline",
    "datasync",
    "datazone",
    "dax",
    "deadline",
    "detective",
    "devicefarm",
    "devops-guru",
    "directconnect",
    "discovery",
    "dlm",
    "dms",
    "docdb",
    "docdb-elastic",
    "drs",
    "ds",
    "ds-data",
    "dsql",
    "dynamodb",
    "dynamodbstreams",
    "ebs",
    "ec2",
    "ec2-instance-connect",
    "ecr",
    "ecr-public",
    "ecs",
    "efs",
    "eks",
    "eks-auth",
    "elasticache",
    "elasticbeanstalk",
    "elastictranscoder",
    "elb",
    "elbv2",
    "emr",
    "emr-containers",
    "emr-serverless",
    "entityresolution",
    "es",
    "events",
    "evidently",
    "evs",
    "finspace",
    "finspace-data",
    "firehose",
    "fis",
    "fms",
    "forecast",
    "forecastquery",
    "frauddetector",
    "freetier",
    "fsx",
    "gamelift",
    "gameliftstreams",
    "geo-maps",
    "geo-places",
    "geo-routes",
    "glacier",
    "globalaccelerator",
    "glue",
    "grafana",
    "greengrass",
    "greengrassv2",
    "groundstation",
    "guardduty",
    "health",
    "healthlake",
    "iam",
    "identitystore",
    "imagebuilder",
    "importexport",
    "inspector",
    "inspector-scan",
    "inspector2",
    "internetmonitor",
    "invoicing",
    "iot",
    "iot-data",
    "iot-jobs-data",
    "iot-managed-integrations",
    "iotanalytics",
    "iotdeviceadvisor",
    "iotevents",
    "iotevents-data",
    "iotfleetwise",
    "iotsecuretunneling",
    "iotsitewise",
    "iotthingsgraph",
    "iottwinmaker",
    "iotwireless",
    "ivs",
    "ivs-realtime",
    "ivschat",
    "kafka",
    "kafkaconnect",
    "kendra",
    "kendra-ranking",
    "keyspaces",
    "keyspacesstreams",
    "kinesis",
    "kinesis-video-archived-media",
    "kinesis-video-media",
    "kinesis-video-signaling",
    "kinesis-video-webrtc-storage",
    "kinesisanalytics",
    "kinesisanalyticsv2",
    "kinesisvideo",
    "kms",
    "lakeformation",
    "lambda",
    "launch-wizard",
    "lex-models",
    "lex-runtime",
    "lexv2-models",
    "lexv2-runtime",
    "license-manager",
    "license-manager-linux-subscriptions",
    "license-manager-user-subscriptions",
    "lightsail",
    "location",
    "logs",
    "lookoutequipment",
    "m2",
    "machinelearning",
    "macie2",
    "mailmanager",
    "managedblockchain",
    "managedblockchain-query",
    "marketplace-agreement",
    "marketplace-catalog",
    "marketplace-deployment",
    "marketplace-entitlement",
    "marketplace-reporting",
    "marketplacecommerceanalytics",
    "mediaconnect",
    "mediaconvert",
    "medialive",
    "mediapackage",
    "mediapackage-vod",
    "mediapackagev2",
    "mediastore",
    "mediastore-data",
    "mediatailor",
    "medical-imaging",
    "memorydb",
    "meteringmarketplace",
    "mgh",
    "mgn",
    "migration-hub-refactor-spaces",
    "migrationhub-config",
    "migrationhuborchestrator",
    "migrationhubstrategy",
    "mpa",
    "mq",
    "mturk",
    "mwaa",
    "mwaa-serverless",
    "neptune",
    "neptune-graph",
    "neptunedata",
    "network-firewall",
    "networkflowmonitor",
    "networkmanager",
    "networkmonitor",
    "notifications",
    "notificationscontacts",
    "oam",
    "observabilityadmin",
    "odb",
    "omics",
    "opensearch",
    "opensearchserverless",
    "organizations",
    "osis",
    "outposts",
    "panorama",
    "partnercentral-channel",
    "partnercentral-selling",
    "payment-cryptography",
    "payment-cryptography-data",
    "pca-connector-ad",
    "pca-connector-scep",
    "pcs",
    "personalize",
    "personalize-events",
    "personalize-runtime",
    "pi",
    "pinpoint",
    "pinpoint-email",
    "pinpoint-sms-voice",
    "pinpoint-sms-voice-v2",
    "pipes",
    "polly",
    "pricing",
    "proton",
    "qapps",
    "qbusiness",
    "qconnect",
    "quicksight",
    "ram",
    "rbin",
    "rds",
    "rds-data",
    "redshift",
    "redshift-data",
    "redshift-serverless",
    "rekognition",
    "repostspace",
    "resiliencehub",
    "resource-explorer-2",
    "resource-groups",
    "resourcegroupstaggingapi",
    "rolesanywhere",
    "route53",
    "route53-recovery-cluster",
    "route53-recovery-control-config",
    "route53-recovery-readiness",
    "route53domains",
    "route53profiles",
    "route53resolver",
    "rtbfabric",
    "rum",
    "s3",
    "s3control",
    "s3outposts",
    "s3tables",
    "s3vectors",
    "sagemaker",
    "sagemaker-a2i-runtime",
    "sagemaker-edge",
    "sagemaker-featurestore-runtime",
    "sagemaker-geospatial",
    "sagemaker-metrics",
    "sagemaker-runtime",
    "savingsplans",
    "scheduler",
    "schemas",
    "sdb",
    "secretsmanager",
    "security-ir",
    "securityhub",
    "securitylake",
    "serverlessrepo",
    "service-quotas",
    "servicecatalog",
    "servicecatalog-appregistry",
    "servicediscovery",
    "ses",
    "sesv2",
    "shield",
    "signer",
    "signin",
    "simspaceweaver",
    "snow-device-management",
    "snowball",
    "sns",
    "socialmessaging",
    "sqs",
    "ssm",
    "ssm-contacts",
    "ssm-guiconnect",
    "ssm-incidents",
    "ssm-quicksetup",
    "ssm-sap",
    "sso",
    "sso-admin",
    "sso-oidc",
    "stepfunctions",
    "storagegateway",
    "sts",
    "supplychain",
    "support",
    "support-app",
    "swf",
    "synthetics",
    "taxsettings",
    "textract",
    "timestream-influxdb",
    "timestream-query",
    "timestream-write",
    "tnb",
    "transcribe",
    "transfer",
    "translate",
    "trustedadvisor",
    "verifiedpermissions",
    "voice-id",
    "vpc-lattice",
    "waf",
    "waf-regional",
    "wafv2",
    "wellarchitected",
    "wisdom",
    "workdocs",
    "workmail",
    "workmailmessageflow",
    "workspaces",
    "workspaces-instances",
    "workspaces-thin-client",
    "workspaces-web",
    "xray",
]
ResourceServiceName = Literal[
    "cloudformation", "cloudwatch", "dynamodb", "ec2", "glacier", "iam", "s3", "sns", "sqs"
]
PaginatorName = Literal[
    "list_cloud_front_origin_access_identities",
    "list_connection_functions",
    "list_connection_groups",
    "list_distribution_tenants",
    "list_distribution_tenants_by_customization",
    "list_distributions",
    "list_distributions_by_connection_function",
    "list_distributions_by_connection_mode",
    "list_distributions_by_trust_store",
    "list_domain_conflicts",
    "list_invalidations",
    "list_invalidations_for_distribution_tenant",
    "list_key_value_stores",
    "list_origin_access_controls",
    "list_public_keys",
    "list_streaming_distributions",
    "list_trust_stores",
]
WaiterName = Literal[
    "distribution_deployed",
    "invalidation_completed",
    "invalidation_for_distribution_tenant_completed",
    "streaming_distribution_deployed",
]



"""
Main interface for cloudfront service.

[Documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cloudfront/)

Copyright 2025 Vlad Emelianov

Usage::

    ```python
    from boto3.session import Session
    from mypy_boto3_cloudfront import (
        Client,
        CloudFrontClient,
        DistributionDeployedWaiter,
        InvalidationCompletedWaiter,
        InvalidationForDistributionTenantCompletedWaiter,
        ListCloudFrontOriginAccessIdentitiesPaginator,
        ListConnectionFunctionsPaginator,
        ListConnectionGroupsPaginator,
        ListDistributionTenantsByCustomizationPaginator,
        ListDistributionTenantsPaginator,
        ListDistributionsByConnectionFunctionPaginator,
        ListDistributionsByConnectionModePaginator,
        ListDistributionsByTrustStorePaginator,
        ListDistributionsPaginator,
        ListDomainConflictsPaginator,
        ListInvalidationsForDistributionTenantPaginator,
        ListInvalidationsPaginator,
        ListKeyValueStoresPaginator,
        ListOriginAccessControlsPaginator,
        ListPublicKeysPaginator,
        ListStreamingDistributionsPaginator,
        ListTrustStoresPaginator,
        StreamingDistributionDeployedWaiter,
    )

    session = Session()
    client: CloudFrontClient = session.client("cloudfront")

    distribution_deployed_waiter: DistributionDeployedWaiter = client.get_waiter("distribution_deployed")
    invalidation_completed_waiter: InvalidationCompletedWaiter = client.get_waiter("invalidation_completed")
    invalidation_for_distribution_tenant_completed_waiter: InvalidationForDistributionTenantCompletedWaiter = client.get_waiter("invalidation_for_distribution_tenant_completed")
    streaming_distribution_deployed_waiter: StreamingDistributionDeployedWaiter = client.get_waiter("streaming_distribution_deployed")

    list_cloud_front_origin_access_identities_paginator: ListCloudFrontOriginAccessIdentitiesPaginator = client.get_paginator("list_cloud_front_origin_access_identities")
    list_connection_functions_paginator: ListConnectionFunctionsPaginator = client.get_paginator("list_connection_functions")
    list_connection_groups_paginator: ListConnectionGroupsPaginator = client.get_paginator("list_connection_groups")
    list_distribution_tenants_by_customization_paginator: ListDistributionTenantsByCustomizationPaginator = client.get_paginator("list_distribution_tenants_by_customization")
    list_distribution_tenants_paginator: ListDistributionTenantsPaginator = client.get_paginator("list_distribution_tenants")
    list_distributions_by_connection_function_paginator: ListDistributionsByConnectionFunctionPaginator = client.get_paginator("list_distributions_by_connection_function")
    list_distributions_by_connection_mode_paginator: ListDistributionsByConnectionModePaginator = client.get_paginator("list_distributions_by_connection_mode")
    list_distributions_by_trust_store_paginator: ListDistributionsByTrustStorePaginator = client.get_paginator("list_distributions_by_trust_store")
    list_distributions_paginator: ListDistributionsPaginator = client.get_paginator("list_distributions")
    list_domain_conflicts_paginator: ListDomainConflictsPaginator = client.get_paginator("list_domain_conflicts")
    list_invalidations_for_distribution_tenant_paginator: ListInvalidationsForDistributionTenantPaginator = client.get_paginator("list_invalidations_for_distribution_tenant")
    list_invalidations_paginator: ListInvalidationsPaginator = client.get_paginator("list_invalidations")
    list_key_value_stores_paginator: ListKeyValueStoresPaginator = client.get_paginator("list_key_value_stores")
    list_origin_access_controls_paginator: ListOriginAccessControlsPaginator = client.get_paginator("list_origin_access_controls")
    list_public_keys_paginator: ListPublicKeysPaginator = client.get_paginator("list_public_keys")
    list_streaming_distributions_paginator: ListStreamingDistributionsPaginator = client.get_paginator("list_streaming_distributions")
    list_trust_stores_paginator: ListTrustStoresPaginator = client.get_paginator("list_trust_stores")
    ```
"""

from .client import CloudFrontClient
from .paginator import (
    ListCloudFrontOriginAccessIdentitiesPaginator,
    ListConnectionFunctionsPaginator,
    ListConnectionGroupsPaginator,
    ListDistributionsByConnectionFunctionPaginator,
    ListDistributionsByConnectionModePaginator,
    ListDistributionsByTrustStorePaginator,
    ListDistributionsPaginator,
    ListDistributionTenantsByCustomizationPaginator,
    ListDistributionTenantsPaginator,
    ListDomainConflictsPaginator,
    ListInvalidationsForDistributionTenantPaginator,
    ListInvalidationsPaginator,
    ListKeyValueStoresPaginator,
    ListOriginAccessControlsPaginator,
    ListPublicKeysPaginator,
    ListStreamingDistributionsPaginator,
    ListTrustStoresPaginator,
)
from .waiter import (
    DistributionDeployedWaiter,
    InvalidationCompletedWaiter,
    InvalidationForDistributionTenantCompletedWaiter,
    StreamingDistributionDeployedWaiter,
)

Client = CloudFrontClient

__all__ = (
    "Client",
    "CloudFrontClient",
    "DistributionDeployedWaiter",
    "InvalidationCompletedWaiter",
    "InvalidationForDistributionTenantCompletedWaiter",
    "ListCloudFrontOriginAccessIdentitiesPaginator",
    "ListConnectionFunctionsPaginator",
    "ListConnectionGroupsPaginator",
    "ListDistributionTenantsByCustomizationPaginator",
    "ListDistributionTenantsPaginator",
    "ListDistributionsByConnectionFunctionPaginator",
    "ListDistributionsByConnectionModePaginator",
    "ListDistributionsByTrustStorePaginator",
    "ListDistributionsPaginator",
    "ListDomainConflictsPaginator",
    "ListInvalidationsForDistributionTenantPaginator",
    "ListInvalidationsPaginator",
    "ListKeyValueStoresPaginator",
    "ListOriginAccessControlsPaginator",
    "ListPublicKeysPaginator",
    "ListStreamingDistributionsPaginator",
    "ListTrustStoresPaginator",
    "StreamingDistributionDeployedWaiter",
)
